==> unrar-nonfree_5.6.6.orig.tar.gz: unrar/rar.hpp <==
#ifndef _RAR_RARCOMMON_
#define _RAR_RARCOMMON_

#include "raros.hpp"
#include "rartypes.hpp"
#include "os.hpp"

#ifdef RARDLL
#include "dll.hpp"
#endif

#include "version.hpp"
#include "rardefs.hpp"
#include "rarlang.hpp"
#include "unicode.hpp"
#include "errhnd.hpp"
#include "secpassword.hpp"
#include "array.hpp"
#include "timefn.hpp"
#include "sha1.hpp"
#include "sha256.hpp"
#include "blake2s.hpp"
#include "hash.hpp"
#include "options.hpp"
#include "rijndael.hpp"
#include "crypt.hpp"
#include "headers5.hpp"
#include "headers.hpp"
#include "pathfn.hpp"
#include "strfn.hpp"
#include "strlist.hpp"
#ifdef _WIN_ALL
#include "isnt.hpp"
#endif
#include "file.hpp"
#include "crc.hpp"
#include "ui.hpp"
#include "filefn.hpp"
#include "filestr.hpp"
#include "find.hpp"
#include "scantree.hpp"
#include "savepos.hpp"
#include "getbits.hpp"
#include "rdwrfn.hpp"
#ifdef USE_QOPEN
#include "qopen.hpp"
#endif
#include "archive.hpp"
#include "match.hpp"
#include "cmddata.hpp"
#include "filcreat.hpp"
#include "consio.hpp"
#include "system.hpp"
#include "log.hpp"
#include "rawint.hpp"
#include "rawread.hpp"
#include "encname.hpp"
#include "resource.hpp"
#include "compress.hpp"

#include "rarvm.hpp"
#include "model.hpp"

#include "threadpool.hpp"

#include "unpack.hpp"



#include "extinfo.hpp"
#include "extract.hpp"



#include "list.hpp"


#include "rs.hpp"
#include "rs16.hpp"
#include "recvol.hpp"
#include "volume.hpp"
#include "smallfn.hpp"

#include "global.hpp"

#if 0
#include "benchmark.hpp"
#endif





#endif

==> unrar-nonfree_7.2.4.orig.tar.gz: unrar/rar.hpp <==
#ifndef _RAR_RARCOMMON_
#define _RAR_RARCOMMON_

#include "raros.hpp"
#include "rartypes.hpp"
#include "os.hpp"

#ifdef RARDLL
#include "dll.hpp"
#endif

#include "version.hpp"
#include "rardefs.hpp"
#include "rarlang.hpp"
#include "rawint.hpp"
#include "unicode.hpp"
#include "errhnd.hpp"
#include "secpassword.hpp"
#include "strlist.hpp"
#include "timefn.hpp"
#include "sha1.hpp"
#include "sha256.hpp"
#include "blake2s.hpp"
#include "hash.hpp"
#include "options.hpp"
#include "rijndael.hpp"
#include "crypt.hpp"
#include "headers5.hpp"
#include "headers.hpp"
#include "pathfn.hpp"
#include "strfn.hpp"
#ifdef _WIN_ALL
#include "isnt.hpp"
#endif
#ifdef PROPAGATE_MOTW
#include "motw.hpp"
#endif
#include "file.hpp"
#include "crc.hpp"
#include "filefn.hpp"
#include "filestr.hpp"
#include "find.hpp"
#include "scantree.hpp"
#include "getbits.hpp"
#include "rdwrfn.hpp"
#ifdef USE_QOPEN
#include "qopen.hpp"
#endif
#include "archive.hpp"
#include "match.hpp"
#include "cmddata.hpp"
#include "ui.hpp"
#include "filcreat.hpp"
#include "consio.hpp"
#include "system.hpp"
#include "log.hpp"
#include "rawread.hpp"
#include "encname.hpp"
#include "resource.hpp"
#include "compress.hpp"

#include "rarvm.hpp"
#include "model.hpp"

#include "threadpool.hpp"

#include "largepage.hpp"

#include "unpack.hpp"



#include "extinfo.hpp"
#include "extract.hpp"



#include "list.hpp"


#include "rs.hpp"
#include "rs16.hpp"



#include "recvol.hpp"
#include "volume.hpp"
#include "smallfn.hpp"

#include "global.hpp"






#endif
